@@ -356,4 +356,33 @@ namespace GPBoost {
 		}
 	}
 
+	void CalcZtVGivenIndices(const data_size_t num_data,
+		const data_size_t num_re,
+		const data_size_t* const random_effects_indices_of_data,
+		const vec_t& v,
+		vec_t& ZtV,
+		bool initialize_zero) {
+		if (initialize_zero) {
+			ZtV = vec_t::Zero(num_re);
+		}
+#pragma omp parallel
+		{
+			vec_t Ztv_private = vec_t::Zero(num_re);
+#pragma omp for
+			for (data_size_t i = 0; i < num_data; ++i) {
+				Ztv_private[random_effects_indices_of_data[i]] += v[i];
+			}
+#pragma omp critical
+			{
+				for (data_size_t i_re = 0; i_re < num_re; ++i_re) {
+					ZtV[i_re] += Ztv_private[i_re];
+				}
+			}//end omp critical
+		}//end omp parallel
+		//Non-parallel version
+		//for (data_size_t i = 0; i < num_data; ++i) {
+		//	ZtV[random_effects_indices_of_data[i]] += v[i];
+		//}
+	}
+
 }  // namespace GPBoost
